#[repr(u8)]pub enum Bidir {
UP = 0,
UP_DOWN = 1,
}Variants
UP = 0
The H counter counts up to its limit condition, then is cleared to zero.
UP_DOWN = 1
The H counter counts up to its limit, then counts down to a limit condition or to 0.
Implementations